@@ -12,7 +12,7 @@
    Copyright 2021, HSPyLib team
 """
 
-from hspylib.core.enums.enumeration import Enumeration
+from core.enums.enumeration import Enumeration
 
 
 class AppType(Enumeration):
