@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   hspylib.main.hspylib.addons.widman
+   main.addons.widman
       @file: widget.py
    @created: Thu, 20 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -14,10 +14,10 @@
 """
 
 from abc import ABC, abstractmethod
-from typing import Tuple
+from typing import List, Tuple
 
-from hspylib.core.enums.exit_code import ExitCode
-from hspylib.modules.cli.icons.font_awesome.awesome import Awesome
+from core.enums.exit_code import ExitCode
+from modules.cli.icons.font_awesome.awesome import Awesome
 
 
 class Widget(ABC):
@@ -45,7 +45,7 @@ HSPyLib Widget: {} v{}
         self._version = version
 
     @abstractmethod
-    def execute(self, *args) -> ExitCode:
+    def execute(self, args: List[str]) -> ExitCode:
         """Execute the widget main flow"""
 
     def cleanup(self) -> None:
