@@ -5,7 +5,7 @@
    TODO Purpose of the file
 
    @project: HSPyLib
-   @package: hspylib.main.hspylib.addons.widman.widgets
+   @package: main.addons.widman.widgets
       @file: widget_time_calc.py
    @created: Thu, 20 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -17,14 +17,14 @@
 
 import math
 import re
-from typing import Optional
+from typing import List, Optional
 
-from hspylib.addons.widman.widget import Widget
-from hspylib.core.enums.exit_code import ExitCode
-from hspylib.core.exception.exceptions import WidgetExecutionError
-from hspylib.core.tools.commons import sysout
-from hspylib.modules.cli.icons.font_awesome.widget_icons import WidgetIcons
-from hspylib.modules.cli.tui.extra.minput.minput import minput, MenuInput
+from addons.widman.widget import Widget
+from core.enums.exit_code import ExitCode
+from core.exception.exceptions import WidgetExecutionError
+from core.tools.commons import sysout
+from modules.cli.icons.font_awesome.widget_icons import WidgetIcons
+from modules.cli.tui.extra.minput.minput import MenuInput, minput
 
 
 class WidgetTimeCalc(Widget):
@@ -48,7 +48,7 @@ class WidgetTimeCalc(Widget):
         self.decimal = False
         self.args = None
 
-    def parse_args(self, *args) -> Optional[ExitCode]:
+    def parse_args(self, args: List[str]) -> Optional[ExitCode]:
         """TODO"""
 
         if (not args or len(args) < 3) and not any(a in args for a in ['-h', '--help']):
@@ -69,10 +69,10 @@ class WidgetTimeCalc(Widget):
 
         return None
 
-    def execute(self, *args) -> ExitCode:
+    def execute(self, args: List[str]) -> ExitCode:
         """TODO"""
 
-        ret_val = self.parse_args(*args)
+        ret_val = self.parse_args(args)
 
         if ret_val is not None:
             return ret_val
@@ -84,8 +84,7 @@ class WidgetTimeCalc(Widget):
                 try:
                     parts = [int(math.floor(float(s))) for s in tm.split(':')]
                 except ValueError:
-                    parts = [0, 0, 0]
-                    ret_val = ExitCode.ERROR
+                    return ExitCode.ERROR
                 f_hours = parts[0] if len(parts) > 0 else 0
                 f_minutes = parts[1] if len(parts) > 1 else 0
                 f_secs = parts[2] if len(parts) > 2 else 0
@@ -107,7 +106,7 @@ class WidgetTimeCalc(Widget):
         else:
             sysout(f"{hours:02d}:{self._decimal(minutes):02d}:{self._decimal(seconds):02d}")
 
-        return ret_val
+        return ExitCode.SUCCESS
 
     def _decimal(self, time_raw: int = 0) -> int:
         """ Convert a raw time into decimal """
