@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @Package: hspylib.main.hspylib.hspylib.config
+   @Package: main.config
       @file: app_config.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -17,10 +17,10 @@ import logging as log
 import os
 from typing import Any, Optional
 
-from hspylib.core.config.properties import Properties
-from hspylib.core.metaclass.singleton import Singleton
-from hspylib.core.tools.commons import log_init, run_dir
-from hspylib.core.tools.preconditions import check_argument, check_state
+from core.config.properties import Properties
+from core.metaclass.singleton import Singleton
+from core.tools.commons import log_init, run_dir, touch_file
+from core.tools.preconditions import check_argument, check_state
 
 
 class AppConfigs(metaclass=Singleton):
@@ -48,6 +48,8 @@ AppConfigs
             if log_file else f"{self._log_dir}/application.log"
         check_state(log_init(self._log_file), "Unable to create logger: {}", self._log_file)
 
+        if not os.path.isfile(f'{resource_dir}/application.properties'):
+            touch_file(f'{resource_dir}/application.properties')
         self._app_properties = Properties(load_dir=self._resource_dir)
         log.info(self)
 
