@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @Package: hspylib.main.hspylib.hspylib.crud
+   @Package: main.crud
       @file: crud_repository.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -16,9 +16,10 @@
 from abc import ABC, abstractmethod
 from typing import List, Optional
 
-from hspylib.core.crud.crud_entity import CrudEntity
 from requests.structures import CaseInsensitiveDict
 
+from core.crud.crud_entity import CrudEntity
+
 
 class CrudRepository(ABC):
     """TODO"""
