@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @Package: hspylib.main.hspylib.hspylib.crud.db.firebase
+   @Package: main.crud.db.firebase
       @file: firebase_config.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -18,14 +18,15 @@ import logging as log
 import os
 import uuid
 
-from hspylib.core.config.app_config import AppConfigs
-from hspylib.core.enums.charset import Charset
-from hspylib.core.enums.http_code import HttpCode
-from hspylib.core.metaclass.singleton import Singleton
-from hspylib.core.tools.preconditions import check_argument, check_state
-from hspylib.modules.fetch.fetch import get
 from requests.structures import CaseInsensitiveDict
 
+from core.config.app_config import AppConfigs
+from core.enums.charset import Charset
+from core.enums.http_code import HttpCode
+from core.metaclass.singleton import Singleton
+from core.tools.preconditions import check_argument, check_state
+from modules.fetch.fetch import get
+
 
 class FirebaseConfig(metaclass=Singleton):
     """TODO"""
