@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.hspylib.tools
+   @package: main.tools
       @file: commons.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -18,13 +18,13 @@ import os
 import pathlib
 import re
 import sys
-from datetime import timedelta, datetime
+from datetime import datetime, timedelta
 from typing import Any, List, Optional, Tuple, Type, Union
 
-from hspylib.core.tools.constants import DATE_TIME_FORMAT
-from hspylib.core.tools.validator import Validator
-from hspylib.modules.cli.vt100.vt_codes import VtCodes
-from hspylib.modules.cli.vt100.vt_colors import VtColors
+from core.tools.constants import DATE_TIME_FORMAT
+from core.tools.validator import Validator
+from modules.cli.vt100.vt_codes import VtCodes
+from modules.cli.vt100.vt_colors import VtColors
 
 # pylint: disable=consider-using-f-string
 LOG_FMT = '{} {} {} {}{} {} '.format(
@@ -59,7 +59,8 @@ def log_init(
     :param level:  TODO
     :param filename:  TODO
     """
-    # if someone tried to log something before log_init is called, Python creates a default handler that
+    # if someone tried to log something before log_init is called, Python creates a default handler that is going to
+    # mess our logs.
     _reset_logger()
 
     create = bool(create_new or not os.path.exists(log_file))
@@ -77,6 +78,7 @@ def log_init(
 
 
 def is_debugging():
+    """TODO"""
     for frame in inspect.stack():
         if frame[1].endswith("pydevd.py"):
             return True
@@ -89,10 +91,11 @@ def now() -> str:
 
 
 def now_ms() -> int:
+    """TODO"""
     return int(datetime.now().timestamp())
 
 
-def read_version(version_filepath: str = ".version") -> Tuple:
+def read_version(version_filepath: str = ".version") -> Tuple[int, int, int]:
     """Retrieve the version from the version file in the form: Tuple[major,minor,build]"""
     try:
         log.info("Reading version from %s", version_filepath)
