@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.modules.cli.icons.emojis.faces
+   @package: main.modules.cli.icons.emojis.faces
       @file: face_smiling.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -13,7 +13,7 @@
    Copyright 2021, HSPyLib team
 """
 
-from hspylib.modules.cli.icons.emojis.emojis import Emoji, emj_print
+from modules.cli.icons.emojis.emojis import emj_print, Emoji
 
 
 class FaceSmiling(Emoji):
