@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.modules.cli.tui.extra.minput
+   @package: main.modules.cli.tui.extra.minput
       @file: minput_utils.py
    @created: Thu, 20 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -14,11 +14,11 @@
 """
 import re
 from abc import ABC
-from typing import Optional, Tuple, Any
+from typing import Any, Optional, Tuple
 
-from hspylib.core.exception.exceptions import InvalidInputError
-from hspylib.core.tools.preconditions import check_argument
-from hspylib.modules.cli.vt100.vt_codes import vt_print
+from core.exception.exceptions import InvalidInputError
+from core.tools.preconditions import check_argument
+from modules.cli.vt100.vt_codes import vt_print
 
 
 class MInputUtils(ABC):
