@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.modules.cli.vt100
+   @package: main.modules.cli.vt100
       @file: vt_colors.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -13,8 +13,8 @@
    Copyright 2021, HSPyLib team
 """
 
-from hspylib.core.enums.enumeration import Enumeration
-from hspylib.modules.cli.vt100.vt_100 import Vt100
+from core.enums.enumeration import Enumeration
+from modules.cli.vt100.vt_100 import Vt100
 
 
 class VtColors(Enumeration):
