@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.modules.qt.promotions
+   @package: main.modules.qt.promotions
       @file: htablemodel.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -15,12 +15,13 @@
 
 import collections
 import logging as log
-from typing import Type, List, TypeVar, Union, Tuple
+from typing import List, Tuple, Type, TypeVar, Union
 
-from PyQt5.QtCore import QAbstractTableModel, QModelIndex, QVariant, Qt
+from PyQt5.QtCore import QAbstractTableModel, QModelIndex, Qt, QVariant
 from PyQt5.QtGui import QColor
 from PyQt5.QtWidgets import QTableView
-from hspylib.core.tools.commons import class_attribute_names, class_attribute_values
+
+from core.tools.commons import class_attribute_names, class_attribute_values
 
 T = TypeVar('T')
 
